@@ -11,6 +11,8 @@ from .DiffEq import euler_method
 from .DiffEq import euler_caushy
 from .DiffEq import runge_kutta
 
-__author__ = "Alexandr Savostianov"
+__all__ = ['euler_method', 'euler_caushy', 'runge_kutta']
 
-__version__ = "0.0.1"
\ No newline at end of file
+__author__ = "Александр Савостьянов, Марк Козлов, Вячеслав Есаков, Артём Радайкин, Лев Памбухчян"
+
+__version__ = "0.0.2"
\ No newline at end of file
